@@ -35,7 +35,7 @@ CPE_REGEX = re.compile(
 
 # CPE Full Regex including unused parameters
 CPE_FULL_REGEX = re.compile(
-    "cpe:?:[^:]+:[^:]+:(?P<vendor>[^:]+):(?P<package>[^:]+):(?P<version>[^:]+):(?P<update>[^:]+):(?P<edition>[^:]+):(?P<lang>[^:]+):(?P<sw_edition>[^:]+):(?P<target_sw>[^:]+):(?P<target_hw>[^:]+):(?P<other>[^:]+)"
+    "cpe:?:[^:]+:(?P<cve_type>[^:]+):(?P<vendor>[^:]+):(?P<package>[^:]+):(?P<version>[^:]+):(?P<update>[^:]+):(?P<edition>[^:]+):(?P<lang>[^:]+):(?P<sw_edition>[^:]+):(?P<target_sw>[^:]+):(?P<target_hw>[^:]+):(?P<other>[^:]+)"
 )
 
 
@@ -219,6 +219,10 @@ class VulnerabilityDetail(object):
         parts = CPE_REGEX.match(cpe_uri)
         # cpe:2.3:a:netaddr_project:netaddr:*:*:*:*:*:ruby:*:*
         all_parts = CPE_FULL_REGEX.match(cpe_uri)
+        if all_parts:
+            cve_type = all_parts.group("cve_type")
+            if cve_type != "a":
+                return cve_type
         if parts:
             type = parts.group("vendor")
             if type in KNOWN_PKG_TYPES:
