@@ -203,7 +203,7 @@ class NpmSource(NvdSource):
                 severity
             )
             exploitabilityScore = score
-            if v.get("metadata", {}).get("exploitability"):
+            if v.get("metadata") and v.get("metadata").get("exploitability"):
                 exploitabilityScore = v.get("metadata").get("exploitability")
             cwe_id = v.get("cwe")
             version = v["vulnerable_versions"]
