@@ -5,7 +5,7 @@ from enum import Enum
 
 from semver import VersionInfo
 
-from vdb.lib import CPE_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
+from vdb.lib import CPE_FULL_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
 
 date_format_str = "%Y-%m-%dT%H:%M:%S"
 
@@ -500,11 +500,16 @@ def parse_cpe(cpe_uri):
     :param cpe_uri: CPE to parse
     :return: Individual parts
     """
-    parts = CPE_REGEX.match(cpe_uri)
+    parts = CPE_FULL_REGEX.match(cpe_uri)
     if parts:
-        return parts.group("vendor"), parts.group("package"), parts.group("version")
+        return (
+            parts.group("vendor"),
+            parts.group("package"),
+            parts.group("version"),
+            parts.group("cve_type"),
+        )
     else:
-        return "", None, None
+        return "", None, None, None
 
 
 def get_default_cve_data(severity):
